/*
 * Copyright (c) 2020-2025 TomTom International B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export class GeoCoordinates {
    getLatitudeDeg() {
        return this._latitude;
    }
    getLongitudeDeg() {
        return this._longitude;
    }
    static checkCoordinateBounds(lon, lat) {
        return (lon >= GeoCoordinates.MIN_LON && lon <= GeoCoordinates.MAX_LON && lat >= GeoCoordinates.MIN_LAT && lat <= GeoCoordinates.MAX_LAT);
    }
    static fromValues(longitude, latitude) {
        if (!GeoCoordinates.checkCoordinateBounds(longitude, latitude)) {
            throw new Error('Coordinates out of bounds');
        }
        const geoCoordinates = new GeoCoordinates();
        geoCoordinates._longitude = longitude;
        geoCoordinates._latitude = latitude;
        return geoCoordinates;
    }
}
/** The Constant MAX_LAT. */
GeoCoordinates.MAX_LAT = 90;
/** The Constant MIN_LAT. */
GeoCoordinates.MIN_LAT = -90;
/** The Constant MAX_LON. */
GeoCoordinates.MAX_LON = 180;
/** The Constant MIN_LON. */
GeoCoordinates.MIN_LON = -180;
//# sourceMappingURL=GeoCoordinates.js.map